bonndit package
===============

Subpackages
-----------

.. toctree::

    bonndit.michi

Submodules
----------

bonndit.base module
-------------------

.. automodule:: bonndit.base
    :members:
    :undoc-members:
    :show-inheritance:

bonndit.constants module
------------------------

.. automodule:: bonndit.constants
    :members:
    :undoc-members:
    :show-inheritance:

bonndit.dki module
------------------

.. automodule:: bonndit.dki
    :members:
    :undoc-members:
    :show-inheritance:

bonndit.gradients module
------------------------

.. automodule:: bonndit.gradients
    :members:
    :undoc-members:
    :show-inheritance:

bonndit.io module
-----------------

.. automodule:: bonndit.io
    :members:
    :undoc-members:
    :show-inheritance:

bonndit.multivoxel module
-------------------------

.. automodule:: bonndit.multivoxel
    :members:
    :undoc-members:
    :show-inheritance:

bonndit.shdeconv module
-----------------------

.. automodule:: bonndit.shdeconv
    :members:
    :undoc-members:
    :show-inheritance:

bonndit.shoredeconv module
--------------------------

.. automodule:: bonndit.shoredeconv
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bonndit
    :members:
    :undoc-members:
    :show-inheritance:
